@@ -1,7 +1,6 @@
 # API reference: https://github.com/kubevirt/application-aware-quota/tree/main/staging/src/kubevirt.io/application-aware-quota-api/pkg/apis/core/v1alpha1
 # TODO: update API reference when OCP doc is available
-from __future__ import annotations
-from typing import Dict, Any
+from typing import Any
 
 from ocp_resources.resource import MissingRequiredArgumentError, Resource
 
@@ -11,8 +10,8 @@ class ApplicationAwareClusterResourceQuota(Resource):
 
     def __init__(
         self,
-        quota: Dict[str, Any] | None = None,
-        selector: Dict[str, Any] | None = None,
+        quota: dict[str, Any] | None = None,
+        selector: dict[str, Any] | None = None,
         **kwargs: Any,
     ) -> None:
         """
